@@ -51,7 +51,7 @@ score_stats_only <- function(null_model, factor_matrix, link_function, P_mat=NUL
                               warning=function(w) w, error=function(e) e)
 
       # We've been getting negative denominators with, for example, very rare SNPs
-      if (!(class(score_denom)[1] %in% c("matrix", "array", "numeric"))) {
+      if (class(score_denom)[1] == "simpleError")  {
         err_msg <- paste('Error in calculating test statistic for factor ', kkk,
                          ' possibly it is constant?  Try removing and rerunning.', sep='')
         stop(err_msg)
@@ -89,7 +89,7 @@ score_stats_only <- function(null_model, factor_matrix, link_function, P_mat=NUL
                             error=function(e) e)
 
     # We've been getting negative denominators with, for example, very rare SNPs
-    if (!(class(score_denom)[1] %in% c("matrix", "array", "numeric"))) {
+    if (class(score_denom)[1] == "simpleError")  {
       err_msg <- paste('Error in calculating test statistic for factor ', kkk,
                        ' - possibly it is constant?  Try removing and rerunning.', sep='')
       stop(err_msg)
